# TensorFlow for Java

> *WARNING*: This version of the Java client is deprecated and has been replaced by a new version that is maintained 
> in its own [repository](https://github.com/tensorflow/java) under the TensorFlow organization. 
>
> For using TensorFlow on a JVM, please refer to new [TensorFlow Java](https://www.tensorflow.org/jvm/install).
> For using TensorFlow on Android, refer instead to [TensorFlow Lite](https://www.tensorflow.org/code/tensorflow/lite/).

Follow this [link](LEGACY.md) for legacy instructions.
